Class: Google::Apis::TpuV2alpha1::BootDiskConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tpu_v2alpha1/classes.rb,
lib/google/apis/tpu_v2alpha1/representations.rb,
lib/google/apis/tpu_v2alpha1/representations.rb

Overview

Boot disk configurations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BootDiskConfig

Returns a new instance of BootDiskConfig.



220
221
222
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 220

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customer_encryption_keyGoogle::Apis::TpuV2alpha1::CustomerEncryptionKey

Customer's encryption key. Corresponds to the JSON property customerEncryptionKey



179
180
181
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 179

def customer_encryption_key
  @customer_encryption_key
end

#disk_size_gbFixnum

Optional. Size of the boot disk in GB. It must be larger than or equal to the size of the image. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


185
186
187
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 185

def disk_size_gb
  @disk_size_gb
end

#enable_confidential_computeBoolean Also known as: enable_confidential_compute?

Optional. Whether the boot disk will be created with confidential compute mode. Corresponds to the JSON property enableConfidentialCompute

Returns:

  • (Boolean)


190
191
192
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 190

def enable_confidential_compute
  @enable_confidential_compute
end

#provisioned_iopsFixnum

Optional. Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. To learn more about IOPS, see Provisioning persistent disk performance. Corresponds to the JSON property provisionedIops

Returns:

  • (Fixnum)


199
200
201
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 199

def provisioned_iops
  @provisioned_iops
end

#provisioned_throughputFixnum

Optional. Indicates how much throughput to provision for the disk. This sets the number of throughput MB per second that the disk can handle. Corresponds to the JSON property provisionedThroughput

Returns:

  • (Fixnum)


205
206
207
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 205

def provisioned_throughput
  @provisioned_throughput
end

#source_imageString

Optional. Image from which boot disk is to be created. If not specified, the default image for the runtime version will be used. Example: projects/$ PROJECT_ID/global/images/$IMAGE_NAME. Corresponds to the JSON property sourceImage

Returns:

  • (String)


212
213
214
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 212

def source_image
  @source_image
end

#storage_poolString

Optional. The storage pool in which the boot disk is created. You can provide this as a partial or full URL to the resource. Corresponds to the JSON property storagePool

Returns:

  • (String)


218
219
220
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 218

def storage_pool
  @storage_pool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



225
226
227
228
229
230
231
232
233
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 225

def update!(**args)
  @customer_encryption_key = args[:customer_encryption_key] if args.key?(:customer_encryption_key)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute)
  @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops)
  @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput)
  @source_image = args[:source_image] if args.key?(:source_image)
  @storage_pool = args[:storage_pool] if args.key?(:storage_pool)
end