Class: Google::Apis::TpuV2alpha1::FailedData
- Inherits:
-
Object
- Object
- Google::Apis::TpuV2alpha1::FailedData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tpu_v2alpha1/classes.rb,
lib/google/apis/tpu_v2alpha1/representations.rb,
lib/google/apis/tpu_v2alpha1/representations.rb
Overview
Further data for the failed state.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::TpuV2alpha1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FailedData
constructor
A new instance of FailedData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FailedData
Returns a new instance of FailedData.
315 316 317 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 315 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::TpuV2alpha1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
313 314 315 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 313 def error @error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
320 321 322 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 320 def update!(**args) @error = args[:error] if args.key?(:error) end |