Class: Google::Apis::TpuV2alpha1::Interval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tpu_v2alpha1/classes.rb,
lib/google/apis/tpu_v2alpha1/representations.rb,
lib/google/apis/tpu_v2alpha1/representations.rb

Overview

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Interval

Returns a new instance of Interval.



544
545
546
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 544

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Optional. Exclusive end of the interval. If specified, a Timestamp matching this interval will have to be before the end. Corresponds to the JSON property endTime

Returns:

  • (String)


536
537
538
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 536

def end_time
  @end_time
end

#start_timeString

Optional. Inclusive start of the interval. If specified, a Timestamp matching this interval will have to be the same or after the start. Corresponds to the JSON property startTime

Returns:

  • (String)


542
543
544
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 542

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



549
550
551
552
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 549

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end