Class: Google::Apis::TpuV2alpha1::QueueingPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tpu_v2alpha1/classes.rb,
lib/google/apis/tpu_v2alpha1/representations.rb,
lib/google/apis/tpu_v2alpha1/representations.rb

Overview

Defines the policy of the QueuedRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueueingPolicy

Returns a new instance of QueueingPolicy.



1556
1557
1558
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#valid_after_durationString

A relative time after which resources may be created. Corresponds to the JSON property validAfterDuration

Returns:

  • (String)


1529
1530
1531
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1529

def valid_after_duration
  @valid_after_duration
end

#valid_after_timeString

An absolute time at which resources may be created. Corresponds to the JSON property validAfterTime

Returns:

  • (String)


1534
1535
1536
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1534

def valid_after_time
  @valid_after_time
end

#valid_intervalGoogle::Apis::TpuV2alpha1::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property validInterval



1542
1543
1544
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1542

def valid_interval
  @valid_interval
end

#valid_until_durationString

A relative time after which resources should not be created. If the request cannot be fulfilled by this time the request will be failed. Corresponds to the JSON property validUntilDuration

Returns:

  • (String)


1548
1549
1550
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1548

def valid_until_duration
  @valid_until_duration
end

#valid_until_timeString

An absolute time after which resources should not be created. If the request cannot be fulfilled by this time the request will be failed. Corresponds to the JSON property validUntilTime

Returns:

  • (String)


1554
1555
1556
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1554

def valid_until_time
  @valid_until_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1561
1562
1563
1564
1565
1566
1567
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1561

def update!(**args)
  @valid_after_duration = args[:valid_after_duration] if args.key?(:valid_after_duration)
  @valid_after_time = args[:valid_after_time] if args.key?(:valid_after_time)
  @valid_interval = args[:valid_interval] if args.key?(:valid_interval)
  @valid_until_duration = args[:valid_until_duration] if args.key?(:valid_until_duration)
  @valid_until_time = args[:valid_until_time] if args.key?(:valid_until_time)
end