Class: Google::Apis::TpuV2alpha1::RunDuration
- Inherits:
-
Object
- Object
- Google::Apis::TpuV2alpha1::RunDuration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tpu_v2alpha1/classes.rb,
lib/google/apis/tpu_v2alpha1/representations.rb,
lib/google/apis/tpu_v2alpha1/representations.rb
Overview
Defines the maximum lifetime of the requested resource.
Instance Attribute Summary collapse
-
#max_run_duration ⇒ String
The maximum duration of the requested resource.
-
#termination_time ⇒ String
The time at which the requested resource will be terminated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RunDuration
constructor
A new instance of RunDuration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RunDuration
Returns a new instance of RunDuration.
1630 1631 1632 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1630 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_run_duration ⇒ String
The maximum duration of the requested resource.
Corresponds to the JSON property maxRunDuration
1623 1624 1625 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1623 def max_run_duration @max_run_duration end |
#termination_time ⇒ String
The time at which the requested resource will be terminated.
Corresponds to the JSON property terminationTime
1628 1629 1630 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1628 def termination_time @termination_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1635 1636 1637 1638 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1635 def update!(**args) @max_run_duration = args[:max_run_duration] if args.key?(:max_run_duration) @termination_time = args[:termination_time] if args.key?(:termination_time) end |