Class: Google::Apis::TpuV2alpha1::ServiceAccount
- Inherits:
-
Object
- Object
- Google::Apis::TpuV2alpha1::ServiceAccount
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tpu_v2alpha1/classes.rb,
lib/google/apis/tpu_v2alpha1/representations.rb,
lib/google/apis/tpu_v2alpha1/representations.rb
Overview
A service account.
Instance Attribute Summary collapse
-
#email ⇒ String
Email address of the service account.
-
#scope ⇒ Array<String>
The list of scopes to be made available for this service account.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAccount
constructor
A new instance of ServiceAccount.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAccount
Returns a new instance of ServiceAccount.
1734 1735 1736 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1734 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email ⇒ String
Email address of the service account. If empty, default Compute service
account will be used.
Corresponds to the JSON property email
1726 1727 1728 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1726 def email @email end |
#scope ⇒ Array<String>
The list of scopes to be made available for this service account. If empty,
access to all Cloud APIs will be allowed.
Corresponds to the JSON property scope
1732 1733 1734 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1732 def scope @scope end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1739 1740 1741 1742 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1739 def update!(**args) @email = args[:email] if args.key?(:email) @scope = args[:scope] if args.key?(:scope) end |