Class: Google::Apis::TpuV2alpha1::Standard

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tpu_v2alpha1/classes.rb,
lib/google/apis/tpu_v2alpha1/representations.rb,
lib/google/apis/tpu_v2alpha1/representations.rb

Overview

Details of a standard reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Standard

Returns a new instance of Standard.



1852
1853
1854
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1852

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#capacity_unitsString

Capacity units this reservation is measured in. Corresponds to the JSON property capacityUnits

Returns:

  • (String)


1826
1827
1828
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1826

def capacity_units
  @capacity_units
end

#intervalGoogle::Apis::TpuV2alpha1::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property interval



1834
1835
1836
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1834

def interval
  @interval
end

#resource_typeString

The resource type of the reservation. Corresponds to the JSON property resourceType

Returns:

  • (String)


1839
1840
1841
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1839

def resource_type
  @resource_type
end

#sizeFixnum

The size of the reservation, in the units specified in the 'capacity_units' field. Corresponds to the JSON property size

Returns:

  • (Fixnum)


1845
1846
1847
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1845

def size
  @size
end

#usageGoogle::Apis::TpuV2alpha1::Usage

Usage details of a reservation. Corresponds to the JSON property usage



1850
1851
1852
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1850

def usage
  @usage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1857
1858
1859
1860
1861
1862
1863
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1857

def update!(**args)
  @capacity_units = args[:capacity_units] if args.key?(:capacity_units)
  @interval = args[:interval] if args.key?(:interval)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @size = args[:size] if args.key?(:size)
  @usage = args[:usage] if args.key?(:usage)
end