Class: Google::Apis::TpuV2alpha1::TPUService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::TpuV2alpha1::TPUService
- Defined in:
- lib/google/apis/tpu_v2alpha1/service.rb
Overview
Cloud TPU API
TPU API provides customers with access to Google TPU technology.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://tpu.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_node(parent, node_object = nil, node_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Creates a node.
-
#create_project_location_queued_resource(parent, queued_resource_object = nil, queued_resource_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Creates a QueuedResource TPU instance.
-
#delete_project_location_node(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Deletes a node.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Empty
Deletes a long-running operation.
-
#delete_project_location_queued_resource(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Deletes a QueuedResource TPU instance.
-
#generate_location_service_identity(parent, generate_service_identity_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::GenerateServiceIdentityResponse
Generates the Cloud TPU service identity for the project.
-
#get_node_guest_attributes(name, get_guest_attributes_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::GetGuestAttributesResponse
Retrieves the guest attributes for the node.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Location
Gets information about a location.
-
#get_project_location_accelerator_type(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::AcceleratorType
Gets AcceleratorType.
-
#get_project_location_node(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Node
Gets the details of a node.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_queued_resource(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::QueuedResource
Gets details of a queued resource.
-
#get_project_location_queued_resource_maintenance_info(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::GetMaintenanceInfoResponse
Gets the maintenance info for a queued resource.
-
#get_project_location_runtime_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::RuntimeVersion
Gets a runtime version.
-
#initialize ⇒ TPUService
constructor
A new instance of TPUService.
-
#list_project_location_accelerator_types(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::ListAcceleratorTypesResponse
Lists accelerator types supported by this API.
-
#list_project_location_nodes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::ListNodesResponse
Lists nodes.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_queued_resources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::ListQueuedResourcesResponse
Lists queued resources.
-
#list_project_location_reservations(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::ListReservationsResponse
Retrieves the reservations for the given project in the given location.
-
#list_project_location_runtime_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::ListRuntimeVersionsResponse
Lists runtime versions supported by this API.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_node(name, node_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Updates the configurations of a node.
-
#perform_maintenance_queued_resource(name, perform_maintenance_queued_resource_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Perform manual maintenance on specific nodes of a QueuedResource.
-
#perform_node_maintenance(name, perform_maintenance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Perform manual maintenance on a node.
-
#reset_queued_resource(name, reset_queued_resource_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Resets a QueuedResource TPU instance.
-
#simulate_node_maintenance_event(name, simulate_maintenance_event_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Simulates a maintenance event.
-
#start_node(name, start_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Starts a node.
-
#stop_node(name, stop_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Stops a node.
Constructor Details
#initialize ⇒ TPUService
Returns a new instance of TPUService.
47 48 49 50 51 52 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-tpu_v2alpha1', client_version: Google::Apis::TpuV2alpha1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
607 608 609 610 611 612 613 614 615 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 607 def cancel_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2alpha1/{+name}:cancel', ) command.response_representation = Google::Apis::TpuV2alpha1::Empty::Representation command.response_class = Google::Apis::TpuV2alpha1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_node(parent, node_object = nil, node_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Creates a node.
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 265 def create_project_location_node(parent, node_object = nil, node_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2alpha1/{+parent}/nodes', ) command.request_representation = Google::Apis::TpuV2alpha1::Node::Representation command.request_object = node_object command.response_representation = Google::Apis::TpuV2alpha1::Operation::Representation command.response_class = Google::Apis::TpuV2alpha1::Operation command.params['parent'] = parent unless parent.nil? command.query['nodeId'] = node_id unless node_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_queued_resource(parent, queued_resource_object = nil, queued_resource_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Creates a QueuedResource TPU instance.
756 757 758 759 760 761 762 763 764 765 766 767 768 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 756 def create_project_location_queued_resource(parent, queued_resource_object = nil, queued_resource_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2alpha1/{+parent}/queuedResources', ) command.request_representation = Google::Apis::TpuV2alpha1::QueuedResource::Representation command.request_object = queued_resource_object command.response_representation = Google::Apis::TpuV2alpha1::Operation::Representation command.response_class = Google::Apis::TpuV2alpha1::Operation command.params['parent'] = parent unless parent.nil? command.query['queuedResourceId'] = queued_resource_id unless queued_resource_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_node(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Deletes a node.
301 302 303 304 305 306 307 308 309 310 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 301 def delete_project_location_node(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2alpha1/{+name}', ) command.response_representation = Google::Apis::TpuV2alpha1::Operation::Representation command.response_class = Google::Apis::TpuV2alpha1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
640 641 642 643 644 645 646 647 648 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 640 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2alpha1/{+name}', ) command.response_representation = Google::Apis::TpuV2alpha1::Empty::Representation command.response_class = Google::Apis::TpuV2alpha1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_queued_resource(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Deletes a QueuedResource TPU instance.
798 799 800 801 802 803 804 805 806 807 808 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 798 def delete_project_location_queued_resource(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2alpha1/{+name}', ) command.response_representation = Google::Apis::TpuV2alpha1::Operation::Representation command.response_class = Google::Apis::TpuV2alpha1::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_location_service_identity(parent, generate_service_identity_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::GenerateServiceIdentityResponse
Generates the Cloud TPU service identity for the project.
75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 75 def generate_location_service_identity(parent, generate_service_identity_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2alpha1/{+parent}:generateServiceIdentity', ) command.request_representation = Google::Apis::TpuV2alpha1::GenerateServiceIdentityRequest::Representation command.request_object = generate_service_identity_request_object command.response_representation = Google::Apis::TpuV2alpha1::GenerateServiceIdentityResponse::Representation command.response_class = Google::Apis::TpuV2alpha1::GenerateServiceIdentityResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_node_guest_attributes(name, get_guest_attributes_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::GetGuestAttributesResponse
Retrieves the guest attributes for the node.
363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 363 def get_node_guest_attributes(name, get_guest_attributes_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2alpha1/{+name}:getGuestAttributes', ) command.request_representation = Google::Apis::TpuV2alpha1::GetGuestAttributesRequest::Representation command.request_object = get_guest_attributes_request_object command.response_representation = Google::Apis::TpuV2alpha1::GetGuestAttributesResponse::Representation command.response_class = Google::Apis::TpuV2alpha1::GetGuestAttributesResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Location
Gets information about a location.
107 108 109 110 111 112 113 114 115 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 107 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha1/{+name}', ) command.response_representation = Google::Apis::TpuV2alpha1::Location::Representation command.response_class = Google::Apis::TpuV2alpha1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_accelerator_type(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::AcceleratorType
Gets AcceleratorType.
188 189 190 191 192 193 194 195 196 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 188 def get_project_location_accelerator_type(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha1/{+name}', ) command.response_representation = Google::Apis::TpuV2alpha1::AcceleratorType::Representation command.response_class = Google::Apis::TpuV2alpha1::AcceleratorType command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_node(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Node
Gets the details of a node.
332 333 334 335 336 337 338 339 340 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 332 def get_project_location_node(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha1/{+name}', ) command.response_representation = Google::Apis::TpuV2alpha1::Node::Representation command.response_class = Google::Apis::TpuV2alpha1::Node command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
671 672 673 674 675 676 677 678 679 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 671 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha1/{+name}', ) command.response_representation = Google::Apis::TpuV2alpha1::Operation::Representation command.response_class = Google::Apis::TpuV2alpha1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_queued_resource(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::QueuedResource
Gets details of a queued resource.
830 831 832 833 834 835 836 837 838 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 830 def get_project_location_queued_resource(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha1/{+name}', ) command.response_representation = Google::Apis::TpuV2alpha1::QueuedResource::Representation command.response_class = Google::Apis::TpuV2alpha1::QueuedResource command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_queued_resource_maintenance_info(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::GetMaintenanceInfoResponse
Gets the maintenance info for a queued resource.
860 861 862 863 864 865 866 867 868 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 860 def get_project_location_queued_resource_maintenance_info(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha1/{+name}:getMaintenanceInfo', ) command.response_representation = Google::Apis::TpuV2alpha1::GetMaintenanceInfoResponse::Representation command.response_class = Google::Apis::TpuV2alpha1::GetMaintenanceInfoResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_runtime_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::RuntimeVersion
Gets a runtime version.
1030 1031 1032 1033 1034 1035 1036 1037 1038 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 1030 def get_project_location_runtime_version(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha1/{+name}', ) command.response_representation = Google::Apis::TpuV2alpha1::RuntimeVersion::Representation command.response_class = Google::Apis::TpuV2alpha1::RuntimeVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_accelerator_types(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::ListAcceleratorTypesResponse
Lists accelerator types supported by this API.
226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 226 def list_project_location_accelerator_types(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha1/{+parent}/acceleratorTypes', ) command.response_representation = Google::Apis::TpuV2alpha1::ListAcceleratorTypesResponse::Representation command.response_class = Google::Apis::TpuV2alpha1::ListAcceleratorTypesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_nodes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::ListNodesResponse
Lists nodes.
399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 399 def list_project_location_nodes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha1/{+parent}/nodes', ) command.response_representation = Google::Apis::TpuV2alpha1::ListNodesResponse::Representation command.response_class = Google::Apis::TpuV2alpha1::ListNodesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
716 717 718 719 720 721 722 723 724 725 726 727 728 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 716 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha1/{+name}/operations', ) command.response_representation = Google::Apis::TpuV2alpha1::ListOperationsResponse::Representation command.response_class = Google::Apis::TpuV2alpha1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_queued_resources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::ListQueuedResourcesResponse
Lists queued resources.
894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 894 def list_project_location_queued_resources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha1/{+parent}/queuedResources', ) command.response_representation = Google::Apis::TpuV2alpha1::ListQueuedResourcesResponse::Representation command.response_class = Google::Apis::TpuV2alpha1::ListQueuedResourcesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_reservations(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::ListReservationsResponse
Retrieves the reservations for the given project in the given location.
998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 998 def list_project_location_reservations(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha1/{+parent}/reservations', ) command.response_representation = Google::Apis::TpuV2alpha1::ListReservationsResponse::Representation command.response_class = Google::Apis::TpuV2alpha1::ListReservationsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_runtime_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::ListRuntimeVersionsResponse
Lists runtime versions supported by this API.
1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 1068 def list_project_location_runtime_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha1/{+parent}/runtimeVersions', ) command.response_representation = Google::Apis::TpuV2alpha1::ListRuntimeVersionsResponse::Representation command.response_class = Google::Apis::TpuV2alpha1::ListRuntimeVersionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::ListLocationsResponse
Lists information about the supported locations for this service. This method
can be called in two ways: * List all public locations: Use the path GET /
v1/locations. * List project-visible locations: Use the path GET /v1/
projects/project_id/locations. This may include public locations as well as
private or other locations specifically visible to the project.
154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 154 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha1/{+name}/locations', ) command.response_representation = Google::Apis::TpuV2alpha1::ListLocationsResponse::Representation command.response_class = Google::Apis::TpuV2alpha1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_node(name, node_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Updates the configurations of a node.
435 436 437 438 439 440 441 442 443 444 445 446 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 435 def patch_project_location_node(name, node_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v2alpha1/{+name}', ) command.request_representation = Google::Apis::TpuV2alpha1::Node::Representation command.request_object = node_object command.response_representation = Google::Apis::TpuV2alpha1::Operation::Representation command.response_class = Google::Apis::TpuV2alpha1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#perform_maintenance_queued_resource(name, perform_maintenance_queued_resource_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Perform manual maintenance on specific nodes of a QueuedResource.
928 929 930 931 932 933 934 935 936 937 938 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 928 def perform_maintenance_queued_resource(name, perform_maintenance_queued_resource_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2alpha1/{+name}:performMaintenanceQueuedResource', ) command.request_representation = Google::Apis::TpuV2alpha1::PerformMaintenanceQueuedResourceRequest::Representation command.request_object = perform_maintenance_queued_resource_request_object command.response_representation = Google::Apis::TpuV2alpha1::Operation::Representation command.response_class = Google::Apis::TpuV2alpha1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#perform_node_maintenance(name, perform_maintenance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Perform manual maintenance on a node.
469 470 471 472 473 474 475 476 477 478 479 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 469 def perform_node_maintenance(name, perform_maintenance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2alpha1/{+name}:performMaintenance', ) command.request_representation = Google::Apis::TpuV2alpha1::PerformMaintenanceRequest::Representation command.request_object = perform_maintenance_request_object command.response_representation = Google::Apis::TpuV2alpha1::Operation::Representation command.response_class = Google::Apis::TpuV2alpha1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#reset_queued_resource(name, reset_queued_resource_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Resets a QueuedResource TPU instance
961 962 963 964 965 966 967 968 969 970 971 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 961 def reset_queued_resource(name, reset_queued_resource_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2alpha1/{+name}:reset', ) command.request_representation = Google::Apis::TpuV2alpha1::ResetQueuedResourceRequest::Representation command.request_object = reset_queued_resource_request_object command.response_representation = Google::Apis::TpuV2alpha1::Operation::Representation command.response_class = Google::Apis::TpuV2alpha1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#simulate_node_maintenance_event(name, simulate_maintenance_event_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Simulates a maintenance event.
502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 502 def simulate_node_maintenance_event(name, simulate_maintenance_event_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2alpha1/{+name}:simulateMaintenanceEvent', ) command.request_representation = Google::Apis::TpuV2alpha1::SimulateMaintenanceEventRequest::Representation command.request_object = simulate_maintenance_event_request_object command.response_representation = Google::Apis::TpuV2alpha1::Operation::Representation command.response_class = Google::Apis::TpuV2alpha1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#start_node(name, start_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Starts a node.
535 536 537 538 539 540 541 542 543 544 545 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 535 def start_node(name, start_node_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2alpha1/{+name}:start', ) command.request_representation = Google::Apis::TpuV2alpha1::StartNodeRequest::Representation command.request_object = start_node_request_object command.response_representation = Google::Apis::TpuV2alpha1::Operation::Representation command.response_class = Google::Apis::TpuV2alpha1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#stop_node(name, stop_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2alpha1::Operation
Stops a node. This operation is only available with single TPU nodes.
568 569 570 571 572 573 574 575 576 577 578 |
# File 'lib/google/apis/tpu_v2alpha1/service.rb', line 568 def stop_node(name, stop_node_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2alpha1/{+name}:stop', ) command.request_representation = Google::Apis::TpuV2alpha1::StopNodeRequest::Representation command.request_object = stop_node_request_object command.response_representation = Google::Apis::TpuV2alpha1::Operation::Representation command.response_class = Google::Apis::TpuV2alpha1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |