Class: Google::Apis::TpuV2alpha1::UpcomingMaintenance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tpu_v2alpha1/classes.rb,
lib/google/apis/tpu_v2alpha1/representations.rb,
lib/google/apis/tpu_v2alpha1/representations.rb

Overview

Upcoming Maintenance notification information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpcomingMaintenance

Returns a new instance of UpcomingMaintenance.



2051
2052
2053
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 2051

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_rescheduleBoolean Also known as: can_reschedule?

Indicates if the maintenance can be customer triggered. Corresponds to the JSON property canReschedule

Returns:

  • (Boolean)


2020
2021
2022
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 2020

def can_reschedule
  @can_reschedule
end

#latest_window_start_timeString

The latest time for the planned maintenance window to start. This timestamp value is in RFC3339 text format. Corresponds to the JSON property latestWindowStartTime

Returns:

  • (String)


2027
2028
2029
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 2027

def latest_window_start_time
  @latest_window_start_time
end

#maintenance_statusString

The status of the maintenance. Corresponds to the JSON property maintenanceStatus

Returns:

  • (String)


2032
2033
2034
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 2032

def maintenance_status
  @maintenance_status
end

#typeString

Defines the type of maintenance. Corresponds to the JSON property type

Returns:

  • (String)


2037
2038
2039
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 2037

def type
  @type
end

#window_end_timeString

The time by which the maintenance disruption will be completed. This timestamp value is in RFC3339 text format. Corresponds to the JSON property windowEndTime

Returns:

  • (String)


2043
2044
2045
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 2043

def window_end_time
  @window_end_time
end

#window_start_timeString

The current start time of the maintenance window. This timestamp value is in RFC3339 text format. Corresponds to the JSON property windowStartTime

Returns:

  • (String)


2049
2050
2051
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 2049

def window_start_time
  @window_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2056
2057
2058
2059
2060
2061
2062
2063
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 2056

def update!(**args)
  @can_reschedule = args[:can_reschedule] if args.key?(:can_reschedule)
  @latest_window_start_time = args[:latest_window_start_time] if args.key?(:latest_window_start_time)
  @maintenance_status = args[:maintenance_status] if args.key?(:maintenance_status)
  @type = args[:type] if args.key?(:type)
  @window_end_time = args[:window_end_time] if args.key?(:window_end_time)
  @window_start_time = args[:window_start_time] if args.key?(:window_start_time)
end