Class: Google::Apis::TpuV2alpha1::Node
- Inherits:
-
Object
- Object
- Google::Apis::TpuV2alpha1::Node
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tpu_v2alpha1/classes.rb,
lib/google/apis/tpu_v2alpha1/representations.rb,
lib/google/apis/tpu_v2alpha1/representations.rb
Overview
A TPU instance.
Instance Attribute Summary collapse
-
#accelerator_config ⇒ Google::Apis::TpuV2alpha1::AcceleratorConfig
A TPU accelerator configuration.
-
#accelerator_type ⇒ String
The type of hardware accelerators associated with this node.
-
#api_version ⇒ String
Output only.
-
#autocheckpoint_enabled ⇒ Boolean
(also: #autocheckpoint_enabled?)
Optional.
-
#boot_disk_config ⇒ Google::Apis::TpuV2alpha1::BootDiskConfig
Boot disk configurations.
-
#cidr_block ⇒ String
The CIDR block that the TPU node will use when selecting an IP address.
-
#create_time ⇒ String
Output only.
-
#data_disks ⇒ Array<Google::Apis::TpuV2alpha1::AttachedDisk>
The additional data disks for the Node.
-
#description ⇒ String
The user-supplied description of the TPU.
-
#health ⇒ String
The health status of the TPU node.
-
#health_description ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#labels ⇒ Hash<String,String>
Resource labels to represent user-provided metadata.
-
#metadata ⇒ Hash<String,String>
Custom metadata to apply to the TPU Node.
-
#multislice_node ⇒ Boolean
(also: #multislice_node?)
Output only.
-
#name ⇒ String
Output only.
-
#network_config ⇒ Google::Apis::TpuV2alpha1::NetworkConfig
Network related configurations.
-
#network_configs ⇒ Array<Google::Apis::TpuV2alpha1::NetworkConfig>
Optional.
-
#network_endpoints ⇒ Array<Google::Apis::TpuV2alpha1::NetworkEndpoint>
Output only.
-
#queued_resource ⇒ String
Output only.
-
#runtime_version ⇒ String
Required.
-
#scheduling_config ⇒ Google::Apis::TpuV2alpha1::SchedulingConfig
Sets the scheduling options for this node.
-
#service_account ⇒ Google::Apis::TpuV2alpha1::ServiceAccount
A service account.
-
#shielded_instance_config ⇒ Google::Apis::TpuV2alpha1::ShieldedInstanceConfig
A set of Shielded Instance options.
-
#state ⇒ String
Output only.
-
#symptoms ⇒ Array<Google::Apis::TpuV2alpha1::Symptom>
Output only.
-
#tags ⇒ Array<String>
Tags to apply to the TPU Node.
-
#upcoming_maintenance ⇒ Google::Apis::TpuV2alpha1::UpcomingMaintenance
Upcoming Maintenance notification information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Node
constructor
A new instance of Node.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Node
Returns a new instance of Node.
1090 1091 1092 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1090 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_config ⇒ Google::Apis::TpuV2alpha1::AcceleratorConfig
A TPU accelerator configuration.
Corresponds to the JSON property acceleratorConfig
937 938 939 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 937 def accelerator_config @accelerator_config end |
#accelerator_type ⇒ String
The type of hardware accelerators associated with this node.
Corresponds to the JSON property acceleratorType
942 943 944 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 942 def accelerator_type @accelerator_type end |
#api_version ⇒ String
Output only. The API version that created this Node.
Corresponds to the JSON property apiVersion
947 948 949 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 947 def api_version @api_version end |
#autocheckpoint_enabled ⇒ Boolean Also known as: autocheckpoint_enabled?
Optional. Whether Autocheckpoint is enabled.
Corresponds to the JSON property autocheckpointEnabled
952 953 954 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 952 def autocheckpoint_enabled @autocheckpoint_enabled end |
#boot_disk_config ⇒ Google::Apis::TpuV2alpha1::BootDiskConfig
Boot disk configurations.
Corresponds to the JSON property bootDiskConfig
958 959 960 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 958 def boot_disk_config @boot_disk_config end |
#cidr_block ⇒ String
The CIDR block that the TPU node will use when selecting an IP address. This
CIDR block must be a /29 block; the Compute Engine networks API forbids a
smaller block, and using a larger block would be wasteful (a node can only
consume one IP address). Errors will occur if the CIDR block has already been
used for a currently existing TPU node, the CIDR block conflicts with any
subnetworks in the user's provided network, or the provided network is peered
with another network that is using that CIDR block.
Corresponds to the JSON property cidrBlock
969 970 971 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 969 def cidr_block @cidr_block end |
#create_time ⇒ String
Output only. The time when the node was created.
Corresponds to the JSON property createTime
974 975 976 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 974 def create_time @create_time end |
#data_disks ⇒ Array<Google::Apis::TpuV2alpha1::AttachedDisk>
The additional data disks for the Node.
Corresponds to the JSON property dataDisks
979 980 981 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 979 def data_disks @data_disks end |
#description ⇒ String
The user-supplied description of the TPU. Maximum of 512 characters.
Corresponds to the JSON property description
984 985 986 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 984 def description @description end |
#health ⇒ String
The health status of the TPU node.
Corresponds to the JSON property health
989 990 991 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 989 def health @health end |
#health_description ⇒ String
Output only. If this field is populated, it contains a description of why the
TPU Node is unhealthy.
Corresponds to the JSON property healthDescription
995 996 997 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 995 def health_description @health_description end |
#id ⇒ Fixnum
Output only. The unique identifier for the TPU Node.
Corresponds to the JSON property id
1000 1001 1002 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1000 def id @id end |
#labels ⇒ Hash<String,String>
Resource labels to represent user-provided metadata.
Corresponds to the JSON property labels
1005 1006 1007 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1005 def labels @labels end |
#metadata ⇒ Hash<String,String>
Custom metadata to apply to the TPU Node. Can set startup-script and shutdown-
script
Corresponds to the JSON property metadata
1011 1012 1013 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1011 def @metadata end |
#multislice_node ⇒ Boolean Also known as: multislice_node?
Output only. Whether the Node belongs to a Multislice group.
Corresponds to the JSON property multisliceNode
1016 1017 1018 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1016 def multislice_node @multislice_node end |
#name ⇒ String
Output only. Immutable. The name of the TPU.
Corresponds to the JSON property name
1022 1023 1024 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1022 def name @name end |
#network_config ⇒ Google::Apis::TpuV2alpha1::NetworkConfig
Network related configurations.
Corresponds to the JSON property networkConfig
1027 1028 1029 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1027 def network_config @network_config end |
#network_configs ⇒ Array<Google::Apis::TpuV2alpha1::NetworkConfig>
Optional. Repeated network configurations for the TPU node. This field is used
to specify multiple networks configs for the TPU node. network_config and
network_configs are mutually exclusive, you can only specify one of them. If
both are specified, an error will be returned.
Corresponds to the JSON property networkConfigs
1035 1036 1037 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1035 def network_configs @network_configs end |
#network_endpoints ⇒ Array<Google::Apis::TpuV2alpha1::NetworkEndpoint>
Output only. The network endpoints where TPU workers can be accessed and sent
work. It is recommended that runtime clients of the node reach out to the 0th
entry in this map first.
Corresponds to the JSON property networkEndpoints
1042 1043 1044 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1042 def network_endpoints @network_endpoints end |
#queued_resource ⇒ String
Output only. The qualified name of the QueuedResource that requested this Node.
Corresponds to the JSON property queuedResource
1047 1048 1049 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1047 def queued_resource @queued_resource end |
#runtime_version ⇒ String
Required. The runtime version running in the Node.
Corresponds to the JSON property runtimeVersion
1052 1053 1054 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1052 def runtime_version @runtime_version end |
#scheduling_config ⇒ Google::Apis::TpuV2alpha1::SchedulingConfig
Sets the scheduling options for this node.
Corresponds to the JSON property schedulingConfig
1057 1058 1059 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1057 def scheduling_config @scheduling_config end |
#service_account ⇒ Google::Apis::TpuV2alpha1::ServiceAccount
A service account.
Corresponds to the JSON property serviceAccount
1062 1063 1064 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1062 def service_account @service_account end |
#shielded_instance_config ⇒ Google::Apis::TpuV2alpha1::ShieldedInstanceConfig
A set of Shielded Instance options.
Corresponds to the JSON property shieldedInstanceConfig
1067 1068 1069 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1067 def shielded_instance_config @shielded_instance_config end |
#state ⇒ String
Output only. The current state for the TPU Node.
Corresponds to the JSON property state
1072 1073 1074 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1072 def state @state end |
#symptoms ⇒ Array<Google::Apis::TpuV2alpha1::Symptom>
Output only. The Symptoms that have occurred to the TPU Node.
Corresponds to the JSON property symptoms
1077 1078 1079 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1077 def symptoms @symptoms end |
#tags ⇒ Array<String>
Tags to apply to the TPU Node. Tags are used to identify valid sources or
targets for network firewalls.
Corresponds to the JSON property tags
1083 1084 1085 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1083 def @tags end |
#upcoming_maintenance ⇒ Google::Apis::TpuV2alpha1::UpcomingMaintenance
Upcoming Maintenance notification information.
Corresponds to the JSON property upcomingMaintenance
1088 1089 1090 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1088 def upcoming_maintenance @upcoming_maintenance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1095 def update!(**args) @accelerator_config = args[:accelerator_config] if args.key?(:accelerator_config) @accelerator_type = args[:accelerator_type] if args.key?(:accelerator_type) @api_version = args[:api_version] if args.key?(:api_version) @autocheckpoint_enabled = args[:autocheckpoint_enabled] if args.key?(:autocheckpoint_enabled) @boot_disk_config = args[:boot_disk_config] if args.key?(:boot_disk_config) @cidr_block = args[:cidr_block] if args.key?(:cidr_block) @create_time = args[:create_time] if args.key?(:create_time) @data_disks = args[:data_disks] if args.key?(:data_disks) @description = args[:description] if args.key?(:description) @health = args[:health] if args.key?(:health) @health_description = args[:health_description] if args.key?(:health_description) @id = args[:id] if args.key?(:id) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @multislice_node = args[:multislice_node] if args.key?(:multislice_node) @name = args[:name] if args.key?(:name) @network_config = args[:network_config] if args.key?(:network_config) @network_configs = args[:network_configs] if args.key?(:network_configs) @network_endpoints = args[:network_endpoints] if args.key?(:network_endpoints) @queued_resource = args[:queued_resource] if args.key?(:queued_resource) @runtime_version = args[:runtime_version] if args.key?(:runtime_version) @scheduling_config = args[:scheduling_config] if args.key?(:scheduling_config) @service_account = args[:service_account] if args.key?(:service_account) @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config) @state = args[:state] if args.key?(:state) @symptoms = args[:symptoms] if args.key?(:symptoms) @tags = args[:tags] if args.key?(:tags) @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance) end |