Class: Google::Apis::TpuV2alpha1::QueuedResource
- Inherits:
-
Object
- Object
- Google::Apis::TpuV2alpha1::QueuedResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tpu_v2alpha1/classes.rb,
lib/google/apis/tpu_v2alpha1/representations.rb,
lib/google/apis/tpu_v2alpha1/representations.rb
Overview
A QueuedResource represents a request for resources that will be placed in a queue and fulfilled when the necessary resources are available.
Instance Attribute Summary collapse
-
#best_effort ⇒ Google::Apis::TpuV2alpha1::BestEffort
BestEffort tier definition.
-
#create_time ⇒ String
Output only.
-
#guaranteed ⇒ Google::Apis::TpuV2alpha1::Guaranteed
Guaranteed tier definition.
-
#name ⇒ String
Output only.
-
#provisioning_model ⇒ String
Optional.
-
#queueing_policy ⇒ Google::Apis::TpuV2alpha1::QueueingPolicy
Defines the policy of the QueuedRequest.
-
#reservation_name ⇒ String
Name of the reservation in which the resource should be provisioned.
-
#run_duration ⇒ Google::Apis::TpuV2alpha1::RunDuration
Defines the maximum lifetime of the requested resource.
-
#spot ⇒ Google::Apis::TpuV2alpha1::Spot
Spot tier definition.
-
#state ⇒ Google::Apis::TpuV2alpha1::QueuedResourceState
QueuedResourceState defines the details of the QueuedResource request.
-
#tpu ⇒ Google::Apis::TpuV2alpha1::Tpu
Details of the TPU resource(s) being requested.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueuedResource
constructor
A new instance of QueuedResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueuedResource
Returns a new instance of QueuedResource.
1427 1428 1429 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1427 def initialize(**args) update!(**args) end |
Instance Attribute Details
#best_effort ⇒ Google::Apis::TpuV2alpha1::BestEffort
BestEffort tier definition.
Corresponds to the JSON property bestEffort
1374 1375 1376 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1374 def best_effort @best_effort end |
#create_time ⇒ String
Output only. The time when the QueuedResource was created.
Corresponds to the JSON property createTime
1379 1380 1381 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1379 def create_time @create_time end |
#guaranteed ⇒ Google::Apis::TpuV2alpha1::Guaranteed
Guaranteed tier definition.
Corresponds to the JSON property guaranteed
1384 1385 1386 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1384 def guaranteed @guaranteed end |
#name ⇒ String
Output only. Immutable. The name of the QueuedResource.
Corresponds to the JSON property name
1389 1390 1391 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1389 def name @name end |
#provisioning_model ⇒ String
Optional. The provisioning model for the resource.
Corresponds to the JSON property provisioningModel
1394 1395 1396 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1394 def provisioning_model @provisioning_model end |
#queueing_policy ⇒ Google::Apis::TpuV2alpha1::QueueingPolicy
Defines the policy of the QueuedRequest.
Corresponds to the JSON property queueingPolicy
1399 1400 1401 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1399 def queueing_policy @queueing_policy end |
#reservation_name ⇒ String
Name of the reservation in which the resource should be provisioned. Format:
projects/project/locations/zone/reservations/reservation
Corresponds to the JSON property reservationName
1405 1406 1407 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1405 def reservation_name @reservation_name end |
#run_duration ⇒ Google::Apis::TpuV2alpha1::RunDuration
Defines the maximum lifetime of the requested resource.
Corresponds to the JSON property runDuration
1410 1411 1412 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1410 def run_duration @run_duration end |
#spot ⇒ Google::Apis::TpuV2alpha1::Spot
Spot tier definition.
Corresponds to the JSON property spot
1415 1416 1417 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1415 def spot @spot end |
#state ⇒ Google::Apis::TpuV2alpha1::QueuedResourceState
QueuedResourceState defines the details of the QueuedResource request.
Corresponds to the JSON property state
1420 1421 1422 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1420 def state @state end |
#tpu ⇒ Google::Apis::TpuV2alpha1::Tpu
Details of the TPU resource(s) being requested.
Corresponds to the JSON property tpu
1425 1426 1427 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1425 def tpu @tpu end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 |
# File 'lib/google/apis/tpu_v2alpha1/classes.rb', line 1432 def update!(**args) @best_effort = args[:best_effort] if args.key?(:best_effort) @create_time = args[:create_time] if args.key?(:create_time) @guaranteed = args[:guaranteed] if args.key?(:guaranteed) @name = args[:name] if args.key?(:name) @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model) @queueing_policy = args[:queueing_policy] if args.key?(:queueing_policy) @reservation_name = args[:reservation_name] if args.key?(:reservation_name) @run_duration = args[:run_duration] if args.key?(:run_duration) @spot = args[:spot] if args.key?(:spot) @state = args[:state] if args.key?(:state) @tpu = args[:tpu] if args.key?(:tpu) end |